#[repr(u32)]pub enum ParamKind {
Uint = 0,
Bool = 1,
Double = 2,
Symbol = 3,
String = 4,
Other = 5,
Invalid = 6,
}Expand description
The different kinds of parameters that can be associated with parameter sets.
(see Z3_mk_params).
Variants
Uint = 0
integer parameters.
Bool = 1
boolean parameters.
Double = 2
double parameters.
Symbol = 3
symbol parameters.
String = 4
string parameters.
Other = 5
all internal parameter kinds which are not exposed in the API.
Invalid = 6
invalid parameter.