pub unsafe extern "C" fn Z3_get_error_code(
c: Z3_context,
) -> Z3_error_codeExpand description
Return the error code for the last API call.
A call to a Z3 function may return a non Z3_OK error code, when it is not used correctly.
pub unsafe extern "C" fn Z3_get_error_code(
c: Z3_context,
) -> Z3_error_codeReturn the error code for the last API call.
A call to a Z3 function may return a non Z3_OK error code, when it is not used correctly.