pub unsafe extern "C" fn Z3_get_string_length(
c: Z3_context,
s: Z3_ast,
) -> c_uintExpand description
Retrieve the length of the unescaped string constant stored in s.
Preconditions
Z3_is_string(c, s)
pub unsafe extern "C" fn Z3_get_string_length(
c: Z3_context,
s: Z3_ast,
) -> c_uintRetrieve the length of the unescaped string constant stored in s.
Z3_is_string(c, s)