Z3_mk_parser_context

Function Z3_mk_parser_context 

pub unsafe extern "C" fn Z3_mk_parser_context(
    c: Z3_context,
) -> Option<Z3_parser_context>
Create a parser context.

A parser context maintains state between calls to Z3_parser_context_parse_string where the caller can pass in a set of SMTLIB2 commands. It maintains all the declarations from previous calls together with of sorts and function declarations (including 0-ary) that are added directly to the context.