Z3_mk_string

Function Z3_mk_string 

pub unsafe extern "C" fn Z3_mk_string(
    c: Z3_context,
    s: Z3_string,
) -> Option<Z3_ast>
Create a string constant out of the string that is passed in The string may contain escape encoding for non-printable characters or characters outside of the basic printable ASCII range. For example, the escape encoding \u{0} represents the character 0 and the encoding \u{100} represents the character 256.