Z3_mk_string_sort

Function Z3_mk_string_sort 

pub unsafe extern "C" fn Z3_mk_string_sort(
    c: Z3_context,
) -> Option<Z3_sort>
Create a sort for unicode strings.

The sort for characters can be changed to ASCII by setting the global parameter encoding to ascii, or alternative to 16 bit characters by setting encoding to bmp.