pub unsafe extern "C" fn Z3_simplifier_get_help(
c: Z3_context,
t: Z3_simplifier,
) -> Z3_stringExpand description
Return a string containing a description of parameters accepted by the given simplifier.
pub unsafe extern "C" fn Z3_simplifier_get_help(
c: Z3_context,
t: Z3_simplifier,
) -> Z3_stringReturn a string containing a description of parameters accepted by the given simplifier.