pub unsafe extern "C" fn Z3_simplifier_using_params(
c: Z3_context,
t: Z3_simplifier,
p: Z3_params,
) -> Option<Z3_simplifier>Expand description
Return a simplifier that applies t using the given set of parameters.
pub unsafe extern "C" fn Z3_simplifier_using_params(
c: Z3_context,
t: Z3_simplifier,
p: Z3_params,
) -> Option<Z3_simplifier>Return a simplifier that applies t using the given set of parameters.