#[repr(u32)]pub enum ErrorCode {
Show 13 variants
Ok = 0,
SortError = 1,
Iob = 2,
InvalidArg = 3,
ParserError = 4,
NoParser = 5,
InvalidPattern = 6,
MemoutFail = 7,
FileAccessError = 8,
InternalFatal = 9,
InvalidUsage = 10,
DecRefError = 11,
Exception = 12,
}Expand description
Z3 error codes (See Z3_get_error_code).
Variants
Ok = 0
No error.
SortError = 1
User tried to build an invalid (type incorrect) AST.
Iob = 2
Index out of bounds.
InvalidArg = 3
Invalid argument was provided.
ParserError = 4
An error occurred when parsing a string or file.
NoParser = 5
Parser output is not available, that is, user didn’t invoke Z3_parse_smtlib2_string or Z3_parse_smtlib2_file.
InvalidPattern = 6
Invalid pattern was used to build a quantifier.
MemoutFail = 7
A memory allocation failure was encountered.
FileAccessError = 8
A file could not be accessed.
InternalFatal = 9
An error internal to Z3 occurred.
InvalidUsage = 10
API call is invalid in the current state.
DecRefError = 11
Trying to decrement the reference counter of an AST that was deleted or the reference counter was not initialized with Z3_inc_ref.
Exception = 12
Internal Z3 exception. Additional details can be retrieved using Z3_get_error_msg.