pub unsafe extern "C" fn Z3_enable_concurrent_dec_ref(c: Z3_context)Expand description
use concurrency control for dec-ref. Reference counting decrements are allowed in separate threads from the context. If this setting is not invoked, reference counting decrements are not going to be thread safe.