pub unsafe extern "C" fn Z3_mk_lstring(
c: Z3_context,
len: c_uint,
s: Z3_string,
) -> Option<Z3_ast>Expand description
Create a string constant out of the string that is passed in It takes the length of the string as well to take into account 0 characters. The string is treated as if it is unescaped so a sequence of characters \u{0} is treated as 5 characters and not the character 0.