pub unsafe extern "C" fn Z3_mk_u32string(
c: Z3_context,
len: c_uint,
chars: *const c_uint,
) -> Option<Z3_ast>Expand description
Create a string constant out of the string that is passed in It takes the length of the string as well to take into account 0 characters. The string is unescaped.